@@ -210,6 +210,10 @@ class DateSchema(TypedDict, total=False):
     ge: date
     lt: date
     gt: date
+    now_op: Literal['past', 'future']
+    # defaults to current local utc offset from `time.localtime().tm_gmtoff`
+    # value is restricted to -86_400 < offset < 86_400 by bounds in generate_self_schema.py
+    now_utc_offset: int
     ref: str
     extra: Any
 
@@ -222,9 +226,22 @@ def date_schema(
     lt: date | None = None,
     gt: date | None = None,
     ref: str | None = None,
+    now_op: Literal['past', 'future'] | None = None,
+    now_utc_offset: int | None = None,
     extra: Any = None,
 ) -> DateSchema:
-    return dict_not_none(type='date', strict=strict, le=le, ge=ge, lt=lt, gt=gt, ref=ref, extra=extra)
+    return dict_not_none(
+        type='date',
+        strict=strict,
+        le=le,
+        ge=ge,
+        lt=lt,
+        gt=gt,
+        now_op=now_op,
+        now_utc_offset=now_utc_offset,
+        ref=ref,
+        extra=extra,
+    )
 
 
 class TimeSchema(TypedDict, total=False):
@@ -258,6 +275,10 @@ class DatetimeSchema(TypedDict, total=False):
     ge: datetime
     lt: datetime
     gt: datetime
+    now_op: Literal['past', 'future']
+    # defaults to current local utc offset from `time.localtime().tm_gmtoff`
+    # value is restricted to -86_400 < offset < 86_400 by bounds in generate_self_schema.py
+    now_utc_offset: int
     ref: str
     extra: Any
 
@@ -269,10 +290,23 @@ def datetime_schema(
     ge: datetime | None = None,
     lt: datetime | None = None,
     gt: datetime | None = None,
+    now_op: Literal['past', 'future'] | None = None,
+    now_utc_offset: int | None = None,
     ref: str | None = None,
     extra: Any = None,
 ) -> DatetimeSchema:
-    return dict_not_none(type='datetime', strict=strict, le=le, ge=ge, lt=lt, gt=gt, ref=ref, extra=extra)
+    return dict_not_none(
+        type='datetime',
+        strict=strict,
+        le=le,
+        ge=ge,
+        lt=lt,
+        gt=gt,
+        now_op=now_op,
+        now_utc_offset=now_utc_offset,
+        ref=ref,
+        extra=extra,
+    )
 
 
 class TimedeltaSchema(TypedDict, total=False):
@@ -316,7 +350,8 @@ JsonType = Literal['null', 'bool', 'int', 'float', 'str', 'list', 'dict']
 
 class IsInstanceSchema(TypedDict, total=False):
     type: Required[Literal['is-instance']]
-    cls: Required[Type[Any]]
+    cls: Required[Any]
+    cls_repr: str
     json_types: Set[JsonType]
     json_function: Callable[[Any], Any]
     ref: str
@@ -324,15 +359,22 @@ class IsInstanceSchema(TypedDict, total=False):
 
 
 def is_instance_schema(
-    cls: Type[Any],
+    cls: Any,
     *,
     json_types: Set[JsonType] | None = None,
     json_function: Callable[[Any], Any] | None = None,
+    cls_repr: str | None = None,
     ref: str | None = None,
     extra: Any = None,
 ) -> IsInstanceSchema:
     return dict_not_none(
-        type='is-instance', cls=cls, json_types=json_types, json_function=json_function, ref=ref, extra=extra
+        type='is-instance',
+        cls=cls,
+        json_types=json_types,
+        json_function=json_function,
+        cls_repr=cls_repr,
+        ref=ref,
+        extra=extra,
     )
 
 
@@ -1058,17 +1100,20 @@ ErrorKind = Literal[
     'bytes_too_long',
     'value_error',
     'assertion_error',
-    'literal_single_error',
-    'literal_multiple_error',
+    'literal_error',
     'date_type',
     'date_parsing',
     'date_from_datetime_parsing',
     'date_from_datetime_inexact',
+    'date_past',
+    'date_future',
     'time_type',
     'time_parsing',
     'datetime_type',
     'datetime_parsing',
     'datetime_object_invalid',
+    'datetime_past',
+    'datetime_future',
     'time_delta_type',
     'time_delta_parsing',
     'frozen_set_type',
