@@ -47,7 +47,8 @@ pub trait Input<'a>: fmt::Debug + ToPyObject {
         None
     }
 
-    fn is_instance(&self, class: &PyType, json_mask: u8) -> PyResult<bool>;
+    // input_ prefix to differentiate from the function on PyAny
+    fn input_is_instance(&self, class: &PyAny, json_mask: u8) -> PyResult<bool>;
 
     fn callable(&self) -> bool {
         false
