@@ -34,10 +34,12 @@ def args(*args, **kwargs):
     'function,args_kwargs,expected_schema',
     [
         [core_schema.any_schema, args(), {'type': 'any'}],
+        [core_schema.any_schema, args(extra=['foot', 'spa']), {'type': 'any', 'extra': ['foot', 'spa']}],
         [core_schema.none_schema, args(), {'type': 'none'}],
         [core_schema.bool_schema, args(), {'type': 'bool'}],
         [core_schema.bool_schema, args(strict=True), {'type': 'bool', 'strict': True}],
         [core_schema.int_schema, args(), {'type': 'int'}],
+        [core_schema.int_schema, args(extra={'fred'}), {'type': 'int', 'extra': {'fred'}}],
         [
             core_schema.int_schema,
             args(multiple_of=5, gt=10, lt=20),
@@ -79,10 +81,11 @@ def args(*args, **kwargs):
             {'type': 'set', 'items_schema': {'type': 'int'}, 'min_length': 4},
         ],
         [
-            core_schema.frozen_set_schema,
+            core_schema.frozenset_schema,
             args({'type': 'int'}, max_length=5),
             {'type': 'frozenset', 'items_schema': {'type': 'int'}, 'max_length': 5},
         ],
+        [core_schema.generator_schema, args({'type': 'int'}), {'type': 'generator', 'items_schema': {'type': 'int'}}],
         [core_schema.dict_schema, args(), {'type': 'dict'}],
         [
             core_schema.dict_schema,
@@ -96,7 +99,7 @@ def args(*args, **kwargs):
         ],
         [
             core_schema.function_after_schema,
-            args(val_function, {'type': 'int'}),
+            args({'type': 'int'}, val_function),
             {'type': 'function', 'mode': 'after', 'function': val_function, 'schema': {'type': 'int'}},
         ],
         [
@@ -136,7 +139,8 @@ def args(*args, **kwargs):
             {
                 'type': 'union',
                 'choices': ({'type': 'int'}, {'type': 'str'}),
-                'custom_error': {'kind': 'foobar', 'message': 'This is Foobar'},
+                'custom_error_kind': 'foobar',
+                'custom_error_message': 'This is Foobar',
             },
         ],
         [
@@ -196,6 +200,16 @@ def args(*args, **kwargs):
             },
         ],
         [core_schema.recursive_reference_schema, args('foo'), {'type': 'recursive-ref', 'schema_ref': 'foo'}],
+        [
+            core_schema.custom_error_schema,
+            args(core_schema.int_schema(), 'foobar', custom_error_message='Hello'),
+            {
+                'type': 'custom_error',
+                'schema': {'type': 'int'},
+                'custom_error_kind': 'foobar',
+                'custom_error_message': 'Hello',
+            },
+        ],
     ],
     ids=ids_function,
 )
@@ -213,5 +227,13 @@ def test_schema_functions(function, args_kwargs, expected_schema):
 
 def test_invalid_custom_error():
     s = core_schema.union_schema({'type': 'int'}, {'type': 'str'}, custom_error_kind='foobar')
-    with pytest.raises(SchemaError, match=r'custom_error \-> message\s+Input should be a valid string'):
+    with pytest.raises(SchemaError, match=r"KeyError: 'custom_error_message'"):
+        SchemaValidator(s)
+
+
+def test_invalid_custom_error_kind():
+    s = core_schema.union_schema(
+        {'type': 'int'}, {'type': 'str'}, custom_error_kind='finite_number', custom_error_message='x'
+    )
+    with pytest.raises(SchemaError, match='custom_error.message should not be provided if kind matches a known error'):
         SchemaValidator(s)
