@@ -26,7 +26,7 @@ def test_model_class():
         }
     )
     assert 'expect_fields_set:true' in plain_repr(v)
-    assert repr(v).startswith('SchemaValidator(name="MyModel", validator=ModelClass(\n')
+    assert repr(v).startswith('SchemaValidator(name="MyModel", validator=NewClass(\n')
     m = v.validate_python({'field_a': 'test', 'field_b': 12})
     assert isinstance(m, MyModel)
     assert m.field_a == 'test'
